<template>
  <input type="text" name="q" value="" placeholder="Поиск товаров" style="width: 100%;" aria-label="Поиск товаров" v-model="inputValue"
         @input="debounceInputHandler"/>

  <div v-if="empty && inputValue !== ''" class="b-search-error">Извините, по вашему запросу ничего не найдено.</div>
  <div class="b-search-result">
    <div v-else class="row b-search-result__row align-items-center position-relative px-3 py-4 position-relative"
         v-for="currency in searchResults">
      <div class="col-auto">
        <img v-bind:src="currency.IMAGE" alt="" class="img-fluid">
      </div>
      <div class="col position-static">
        <div class="row">
          <div class="col-12 position-static">
            <a v-bind:href="currency.URL" class=" b-prod-name stretched-link">
              {{ currency.NAME }}
            </a>
          </div>
          <div class="col-12">
            <div class="text-grey">Артикул: {{ currency.ART }}</div>
          </div>
          <div class="col-12">
            <div class="b-price">
              <span v-if="currency.PRICE !== null"><b>{{ currency.PRICE }}</b></span>
              <span v-else>Под заказ</span>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>

  <img src="/images/v3/lupa.svg" class="b-search-ico">
</template>

<script>

function debounce(func, wait, immediate) {
  var timeout;
  return function () {
    var context = this, args = arguments;
    var later = function () {
      timeout = null;
      if (!immediate) func.apply(context, args);
    };
    var callNow = immediate && !timeout;
    clearTimeout(timeout);
    timeout = setTimeout(later, wait);
    if (callNow) func.apply(context, args);
  };
}

export default {
  name: "Search",

  data() {
    return {
      inputValue: '',
      searchResults: [],
      loading: true,
      empty: false,
      errored: false,
    }
  },


  methods: {
    fetchResults(query) {
      axios
          .get('/tools/php/search.php?q=' + query)
          .then(response => {
            this.searchResults = response.data;
            if (this.searchResults.length <= 0) {
              this.empty = true;
            } else {
              this.empty = false;
            }
            console.log(this.searchResults)
          })
          .catch(error => {
            console.log(error);
            this.errored = true;
          })
          .finally(() => (
              this.loading = false
          ));
    },
    debounceInputHandler: debounce(function (e) {
      let some = e.target.value;
      this.fetchResults(some)
    }, 300)
  }
}
</script>

<style scoped>
</style>
